pub fn codegen_error(
location: SourceLocation,
message: impl Display,
help: impl Display,
) -> ErrorExpand description
Create a code generation error with location and helpful guidance.
pub fn codegen_error(
location: SourceLocation,
message: impl Display,
help: impl Display,
) -> ErrorCreate a code generation error with location and helpful guidance.