pub fn syntax_error(
location: SourceLocation,
message: impl Display,
help: impl Display,
) -> ErrorExpand description
Create a syntax error with location and helpful guidance.
pub fn syntax_error(
location: SourceLocation,
message: impl Display,
help: impl Display,
) -> ErrorCreate a syntax error with location and helpful guidance.