pub struct Error { /* private fields */ }Expand description
An error type that extends anyhow::Error with named fields.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn with_field<V>(self, key: &'static str, value: V) -> Errorwhere
V: Display,
pub fn with_field<V>(self, key: &'static str, value: V) -> Errorwhere
V: Display,
Add a named field to this error.
Sourcepub fn with_field_debug<V>(self, key: &'static str, value: V) -> Errorwhere
V: Debug,
pub fn with_field_debug<V>(self, key: &'static str, value: V) -> Errorwhere
V: Debug,
Add a named field with debug formatting to this error.
Sourcepub fn get_field(&self, key: &str) -> Option<&str>
pub fn get_field(&self, key: &str) -> Option<&str>
Get a specific field value by key, this is an O(n) operation.
Sourcepub fn context<C>(self, context: C) -> Error
pub fn context<C>(self, context: C) -> Error
Add context to this error, see anyhow::Context for more details.
Sourcepub fn with_context<C, F>(self, f: F) -> Error
pub fn with_context<C, F>(self, f: F) -> Error
Add context to this error with a closure, see anyhow::Context for more details.
Sourcepub fn root_cause(&self) -> &dyn Error
pub fn root_cause(&self) -> &dyn Error
Get the root cause of this error.
Sourcepub fn downcast_ref<E>(&self) -> Option<&E>
pub fn downcast_ref<E>(&self) -> Option<&E>
Downcast the error to a reference to a concrete type.
Sourcepub fn downcast_mut<E>(&mut self) -> Option<&mut E>
pub fn downcast_mut<E>(&mut self) -> Option<&mut E>
Downcast the error to a mutable reference to a concrete type.