Macros for reducing code duplication in the python-ast library.
Macro for generating test functions for AST parsing.
Reduces duplication in test code. Asserts that both parsing and code
generation succeed and that the generated stream is non-empty, so codegen
regressions actually fail the test.
Macro for generating Node trait implementations with optional position fields.
This macro automatically implements the Node trait for types that have position fields.